# wfdanielpackagetest

[![Python](https://img.shields.io/pypi/pyversions/wfdanielpackagetest)](https://img.shields.io/pypi/pyversions/wfdanielpackagetest)
[![Pypi](https://img.shields.io/pypi/v/wfdanielpackagetest)](https://pypi.org/project/wfdanielpackagetest/)
[![LOC](https://sloc.xyz/github/danielmen-mx/wfdanielpackagetest/?category=code)](https://github.com/danielmen-mx/wfdanielpackagetest/)
[![Downloads](https://static.pepy.tech/personalized-badge/wfdanielpackagetest?period=month&units=international_system&left_color=grey&right_color=brightgreen&left_text=PyPI%20downloads/month)](https://pepy.tech/project/wfdanielpackagetest)
[![Downloads](https://static.pepy.tech/personalized-badge/wfdanielpackagetest?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/wfdanielpackagetest)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/danielmen-mx/wfdanielpackagetest/blob/master/LICENSE)
[![Forks](https://img.shields.io/github/forks/danielmen-mx/wfdanielpackagetest.svg)](https://github.com/danielmen-mx/wfdanielpackagetest/network)
[![Issues](https://img.shields.io/github/issues/danielmen-mx/wfdanielpackagetest.svg)](https://github.com/danielmen-mx/wfdanielpackagetest/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

### Install wfdanielpackagetest from PyPi.
```bash
pip install wfdanielpackagetest
```

#### Example
```python
  # Import library
  from wfdanielpackagetest import Wfdanielpackagetest
  # Initialize
  model = Wfdanielpackagetest(message='Daniel')
  # Run the model
  model.show()
```